@@ -8,9 +8,6 @@
 
 class RectC;
 
-#define DEM_DOWNLOAD_WARNING 4
-#define DEM_DOWNLOAD_LIMIT   1024
-
 class DEMLoader : public QObject
 {
 	Q_OBJECT
@@ -21,8 +18,8 @@ public:
 	void setUrl(const QString &url) {_url = url;}
 	void setAuthorization(const Authorization &authorization);
 
-	int numTiles(const RectC &rect) const;
-	bool loadTiles(const RectC &rect);
+	int numTiles(const RectC &rect, int limit = 0) const;
+	bool loadTiles(const RectC &rect, int limit = 0);
 	bool checkTiles(const RectC &rect) const;
 
 	const QString &url() const {return _url;}
