@@ -155,10 +155,12 @@ JNXMap::~JNXMap()
 }
 
 void JNXMap::load(const Projection &in, const Projection &out,
-  qreal deviceRatio, bool hidpi, int layer)
+  qreal deviceRatio, bool hidpi, bool hillShading, int style, int layer)
 {
 	Q_UNUSED(out);
+	Q_UNUSED(hillShading);
 	Q_UNUSED(layer);
+	Q_UNUSED(style);
 
 	_projection = in;
 	_mapRatio = hidpi ? deviceRatio : 1.0;
