@@ -31,7 +31,7 @@ public:
 	Coordinates xy2ll(const QPointF &p);
 
 	void load(const Projection &in, const Projection &out, qreal deviceRatio,
-	  bool hidpi, int style, int layer);
+	  bool hidpi, bool hillShading, int style, int layer);
 	void unload();
 
 	void draw(QPainter *painter, const QRectF &rect, Flags flags);
