@@ -214,15 +214,17 @@ void WMSMap::draw(QPainter *painter, const QRectF &rect, Flags flags)
 	QList<FileTile> renderTiles;
 	for (int i = 0; i < fetchTiles.count(); i++) {
 		const TileLoader::Tile &t = fetchTiles.at(i);
-		if (t.files().first().isNull())
+		const QString &path = t.files().first();
+
+		if (path.isNull() || path == NULLFILE)
 			continue;
 
 		QPixmap pm;
-		if (QPixmapCache::find(t.files().first(), &pm)) {
+		if (QPixmapCache::find(path, &pm)) {
 			QPointF tp(t.xy().x() * tileSize(), t.xy().y() * tileSize());
 			drawTile(painter, pm, tp);
 		} else
-			renderTiles.append(FileTile(t.xy(), t.files().first()));
+			renderTiles.append(FileTile(t.xy(), path));
 	}
 
 	QFuture<void> future = QtConcurrent::map(renderTiles, &FileTile::load);
